==> ruby-web-common-0.5.0.tgz: package/src/components/progress_stepper/index.tsx <==
// node modules
import React, { FC, Fragment } from 'react';

// local components
import { Typography } from "../typography";

// local files
import { theming } from "../../theme";
import { getCorrectInput, getCorrectColor, getIndexColorToTitle } from "./utils";
import { uniqIdGenerator } from "../../utils";
import { useStyles } from "./styles";

export interface ProgressStepperProps {
    steps: number,
    colors: string[] | string;
    percents: number;
    title: string
}

export const ProgressStepper: FC<ProgressStepperProps> = ({
    steps,
    colors,
    percents = 0,
    title
}) => {
    const {
        wrapper,
        cercle,
        bar,
        coverBlock,
        thinBlock,
        root
    } = useStyles({ theme: theming.useTheme() })
    const generatedArray = new Array(steps + 1).fill(true);
    let correctPercents = percents <= 0 || isNaN(percents) ? 1 : percents;
    correctPercents = correctPercents > 100 ? 100 : correctPercents;

    return (
        <div className={root}>
            <div className={wrapper}>
                {generatedArray.map((item, i) => {
                    return (
                        <Fragment key={uniqIdGenerator()}>
                            {!!i && (<span
                                style={{
                                    width: `calc(${i}/${steps} * 100%)`,
                                    background: colors[i - 1],
                                    zIndex: steps + 1 - i,
                                }}
                                className={bar}
                            />)}
                            <span
                                style={{
                                    left: `calc(${i}/${steps} * 100%)`,
                                    zIndex: generatedArray.length + 2,
                                    background: getCorrectColor(i, steps, percents, colors)
                                }}
                                className={cercle}
                            >
                            {getCorrectInput(i, steps, correctPercents)}
                        </span>
                        </Fragment>
                    )
                })}
                <div
                    style={{ zIndex: generatedArray.length + 1, width: `calc(100% - ${correctPercents}%)` }}
                    className={coverBlock}
                >
                    <div className={thinBlock}/>
                </div>
            </div>
            <Typography
                style={{ color: colors[getIndexColorToTitle(correctPercents, steps, colors)]}}
                variant="h4"
            >
                {title}
            </Typography>
        </div>
    )
};

==> ruby-web-common-0.6.0.tgz: package/src/components/progress_stepper/index.tsx <==
// node modules
import React, { FC, Fragment } from 'react';

// local components
import { Typography } from "../typography";

// local files
import { theming } from "../../theme";
import { getCorrectInput, getCorrectColor, getIndexColorToTitle } from "./utils";
import { uniqIdGenerator } from "../../utils";
import { useStyles } from "./styles";

export interface ProgressStepperProps {
    steps: number,
    colors: string[] | string;
    percents: number;
    title: string
}

export const ProgressStepper: FC<ProgressStepperProps> = ({
    steps,
    colors,
    percents = 0,
    title
}) => {
    const {
        wrapper,
        cercle,
        bar,
        coverBlock,
        thinBlock,
        root
    } = useStyles({ theme: theming.useTheme() })
    const generatedArray = new Array(steps + 1).fill(true);
    let correctPercents = percents <= 0 || isNaN(percents) ? 1 : percents;
    correctPercents = correctPercents > 100 ? 100 : correctPercents;

    return (
        <div className={root}>
            <div className={wrapper}>
                {generatedArray.map((_, i) => {
                    return (
                        <Fragment key={uniqIdGenerator()}>
                            {!!i && (<span
                                style={{
                                    width: `calc(${i}/${steps} * 100%)`,
                                    background: colors[i - 1],
                                    zIndex: steps + 1 - i,
                                }}
                                className={bar}
                            />)}
                            <span
                                style={{
                                    left: `calc(${i}/${steps} * 100%)`,
                                    zIndex: generatedArray.length + 2,
                                    background: getCorrectColor(i, steps, percents, colors)
                                }}
                                className={cercle}
                            >
                            {getCorrectInput(i, steps, correctPercents)}
                        </span>
                        </Fragment>
                    )
                })}
                <div
                    style={{ zIndex: generatedArray.length + 1, width: `calc(100% - ${correctPercents}%)` }}
                    className={coverBlock}
                >
                    <div className={thinBlock}/>
                </div>
            </div>
            <Typography
                style={{ color: colors[getIndexColorToTitle(correctPercents, steps, colors)]}}
                variant="h4"
            >
                {title}
            </Typography>
        </div>
    )
};
